/** 
 * @author ngel Arias Romero. 
 * UOC - TFC SaveMeSafe 2015
 */
package ejb;

import java.util.Collection;
import java.util.Iterator;

import javax.ejb.Stateless;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;
import javax.persistence.PersistenceException;

import jpa.AccountGroupJPA;
import jpa.AccountJPA;
import jpa.AdditionalAccountInfoJPA;
import jpa.UserJPA;

// TODO: Auto-generated Javadoc
/**
 * EJB Session Bean Class.
 */
@Stateless
public class AccountsFacadeBean implements AccountsFacadeRemote {

	// Persistence Unit Context
	/** The entman. */
	@PersistenceContext(unitName = "SaveMeSafe")
	private EntityManager entman;

	/* (non-Javadoc)
	 * @see ejb.AccountsFacadeRemote#listAccountGroupsByUser(java.lang.String)
	 */
	@Override
	public Collection<?> listAccountGroupsByUser(String userName) {
		Collection<AccountGroupJPA> accountGroupByUser = null;
		try {
			@SuppressWarnings("unchecked")
			Collection<UserJPA> userData = entman
					.createQuery("FROM UserJPA b WHERE b.name = :name")
					.setParameter("name", userName).getResultList();
			if (!userData.isEmpty()) {
				Iterator<UserJPA> iter = userData.iterator();
				UserJPA element = iter.next();
				accountGroupByUser = element.getGroups();
			}

		} catch (PersistenceException e) {
			System.out.println(e);
		}
		return accountGroupByUser;
	}

	/* (non-Javadoc)
	 * @see ejb.AccountsFacadeRemote#listAccountsByAccountGroup(java.lang.String, java.lang.String)
	 */
	@Override
	public Collection<?> listAccountsByAccountGroup(String userName,
			String accountGroupName) {
		Collection<AccountJPA> accounts = null;

		@SuppressWarnings("unchecked")
		Collection<AccountGroupJPA> accountGroupByUser = (Collection<AccountGroupJPA>) listAccountGroupsByUser(userName);
		for (AccountGroupJPA number : accountGroupByUser) {
			if (number.getName().equalsIgnoreCase(accountGroupName)) {
				accounts = number.getAccounts();
			}
		}
		// TODO Auto-generated method stub
		return accounts;
	}

	/* (non-Javadoc)
	 * @see ejb.AccountsFacadeRemote#showAccountGroup(java.lang.String)
	 */
	@Override
	public AccountJPA showAccountGroup(String accountGroupName) {
		// TODO Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see ejb.AccountsFacadeRemote#showAccountByAccountGroup(java.lang.String, java.lang.String)
	 */
	@Override
	public AccountJPA showAccountByAccountGroup(String groupName,
			String accountName) {
		// TODO Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see ejb.AccountsFacadeRemote#saveAccountGroup(jpa.AccountGroupJPA)
	 */
	@Override
	public AccountGroupJPA saveAccountGroup(AccountGroupJPA newAccountGroup) {
		// TODO Auto-generated method stub

		try {

			AccountGroupJPA persistedAccount = entman.find(
					AccountGroupJPA.class, newAccountGroup.getId());
			if (persistedAccount != null) {
				return entman.merge(newAccountGroup);
			} else {
				AccountGroupJPA merged = entman.merge(newAccountGroup);
				entman.persist(entman.merge(merged));
				entman.flush();
				return merged;
			}
		} catch (PersistenceException e) {
			e.printStackTrace();
		}
		return null;
	}

	/* (non-Javadoc)
	 * @see ejb.AccountsFacadeRemote#saveAccount(jpa.AccountJPA)
	 */
	@Override
	public AccountJPA saveAccount(AccountJPA newAccount) {
		// TODO Auto-generated method stub
		try {

			AccountJPA persistedAccount = entman.find(AccountJPA.class,
					newAccount.getId());
			if (persistedAccount != null) {
				return entman.merge(newAccount);
			} else {
				AccountJPA merged = entman.merge(newAccount);
				entman.persist(merged);
				entman.flush();
				return merged;
			}
			// return newAccount;
		} catch (PersistenceException e) {
			e.printStackTrace();
		}
		return null;
	}

	/* (non-Javadoc)
	 * @see ejb.AccountsFacadeRemote#saveAdditionalAccountInfoJPA(jpa.AdditionalAccountInfoJPA)
	 */
	@Override
	public AdditionalAccountInfoJPA saveAdditionalAccountInfoJPA(
			AdditionalAccountInfoJPA newAccountInfo) {
		// TODO Auto-generated method stub
		try {

			AdditionalAccountInfoJPA persistedAccount = entman.find(
					AdditionalAccountInfoJPA.class, newAccountInfo.getId());
			if (persistedAccount != null) {
				return entman.merge(newAccountInfo);
			} else {
				AdditionalAccountInfoJPA merged = entman.merge(newAccountInfo);
				entman.persist(merged);
				entman.flush();
				return merged;
			}
			// return newAccount;
		} catch (PersistenceException e) {
			e.printStackTrace();
		}
		return null;
	}

	/* (non-Javadoc)
	 * @see ejb.AccountsFacadeRemote#deleteAccount(jpa.AccountJPA)
	 */
	@Override
	public Boolean deleteAccount(AccountJPA newAccount) {

		try {
			AccountJPA persistedAccount = entman.find(AccountJPA.class,
					newAccount.getId());
			if (persistedAccount != null) {
				entman.remove(persistedAccount);
			} else {
				AccountJPA merged = entman.merge(newAccount);
				entman.remove(merged);
				entman.flush();

			}
			return true;
		} catch (PersistenceException e) {
			System.out.println(e);
		}
		return false;
	}

	/* (non-Javadoc)
	 * @see ejb.AccountsFacadeRemote#deleteAccountGroup(jpa.AccountGroupJPA)
	 */
	@Override
	public Boolean deleteAccountGroup(AccountGroupJPA newAccount) {
		// TODO Auto-generated method stub
		try {
			AccountGroupJPA persistedAccount = entman.find(
					AccountGroupJPA.class, newAccount.getId());
			if (persistedAccount != null) {
				entman.remove(persistedAccount);
			} else {
				AccountGroupJPA merged = entman.merge(newAccount);
				entman.remove(merged);
				entman.flush();

			}
			return true;
		} catch (PersistenceException e) {
			System.out.println(e);
		}
		return false;
	}

	/* (non-Javadoc)
	 * @see ejb.AccountsFacadeRemote#updateEncryptedData(java.lang.String, java.lang.String)
	 */
	@Override
	public Boolean updateEncryptedData(String userName, String newMasterPassword) {

		if (userName == null || newMasterPassword == null)
			return false;

		@SuppressWarnings("unchecked")
		Collection<AccountGroupJPA> accountGroupList = (Collection<AccountGroupJPA>) listAccountGroupsByUser(userName);
		if (accountGroupList != null && !accountGroupList.isEmpty())
			for (Iterator<AccountGroupJPA> iter2 = accountGroupList.iterator(); iter2
					.hasNext();) {
				AccountGroupJPA grupo = iter2.next();
				grupo.getUser().setPassword(newMasterPassword);
				saveAccountGroup(grupo);
				Collection<AccountJPA> accountList = grupo.getAccounts();
				for (Iterator<AccountJPA> iter3 = accountList.iterator(); iter3
						.hasNext();) {
					AccountJPA cuenta = iter3.next();
					cuenta.getOwnerGroup().getUser()
							.setPassword(newMasterPassword);
					saveAccount(cuenta);

					Collection<AdditionalAccountInfoJPA> accountInfoList = cuenta
							.getAdditionalInfo();
					for (Iterator<AdditionalAccountInfoJPA> iter4 = accountInfoList
							.iterator(); iter4.hasNext();) {
						AdditionalAccountInfoJPA info = iter4
								.next();
						info.getOwnerAccount().getOwnerGroup().getUser()
								.setPassword(newMasterPassword);
						saveAdditionalAccountInfoJPA(info);
					}
				}
			}
		return true;
	}

	/* (non-Javadoc)
	 * @see ejb.AccountsFacadeRemote#addAdditionalAccountInfo(jpa.AdditionalAccountInfoJPA)
	 */
	@Override
	public AdditionalAccountInfoJPA addAdditionalAccountInfo(
			AdditionalAccountInfoJPA accountInfo) {
		try {

			AdditionalAccountInfoJPA persistedAdditonalInfo = entman.find(
					AdditionalAccountInfoJPA.class, accountInfo.getId());
			if (persistedAdditonalInfo != null) {
				return entman.merge(persistedAdditonalInfo);
			} else {
				AdditionalAccountInfoJPA merged = entman.merge(accountInfo);
				entman.persist(entman.merge(merged));
				entman.flush();
				return accountInfo;
			}
		} catch (PersistenceException e) {
			e.printStackTrace();
		}
		return null;
	}

	/* (non-Javadoc)
	 * @see ejb.AccountsFacadeRemote#listAdditionalAccountInfoJPAByAccount(int)
	 */
	@Override
	public Collection<?> listAdditionalAccountInfoJPAByAccount(int idAccount) {
		Collection<AdditionalAccountInfoJPA> accountGroupByUser = null;
		try {
			AccountJPA userData = entman.find(AccountJPA.class, idAccount);
			if (userData != null)
				return accountGroupByUser = userData.getAdditionalInfo();
			return null;

		} catch (PersistenceException e) {
			System.out.println(e);
		}
		return accountGroupByUser;
	}

	/* (non-Javadoc)
	 * @see ejb.AccountsFacadeRemote#showAccountGroup(int)
	 */
	@Override
	public AccountJPA showAccountGroup(int id) {
		return entman.find(AccountJPA.class, id);
	}

	/* (non-Javadoc)
	 * @see ejb.AccountsFacadeRemote#deleteAdditionalAccountInfo(jpa.AdditionalAccountInfoJPA)
	 */
	@Override
	public Boolean deleteAdditionalAccountInfo(
			AdditionalAccountInfoJPA accountInfo) {
		AdditionalAccountInfoJPA persistedInfo = entman.find(
				AdditionalAccountInfoJPA.class, accountInfo.getId());
		if (persistedInfo != null) {
			entman.remove(persistedInfo);
		} else {
			AdditionalAccountInfoJPA merged = entman.merge(accountInfo);
			entman.remove(merged);
			entman.flush();
		}
		return true;
	}
}
