/** 
 * @author ngel Arias Romero. 
 * UOC - TFC SaveMeSafe 2015
 */
package ejb;

import java.util.Collection;

import javax.ejb.Remote;

import jpa.AccountGroupJPA;
import jpa.AccountJPA;
import jpa.AdditionalAccountInfoJPA;

// TODO: Auto-generated Javadoc
/**
 * Session EJB Remote Interfaces.
 */
@Remote
public interface AccountsFacadeRemote {
	
	/**
	 * Remotely invoked method.
	 *
	 * @param newAccountGroup the new account group
	 * @return the account group jpa
	 */
	public AccountGroupJPA saveAccountGroup(AccountGroupJPA newAccountGroup);

	/**
	 * Save account.
	 *
	 * @param newAccount the new account
	 * @return the account jpa
	 */
	public AccountJPA saveAccount(AccountJPA newAccount);

	/**
	 * Delete account.
	 *
	 * @param newAccount the new account
	 * @return the boolean
	 */
	public Boolean deleteAccount(AccountJPA newAccount);

	/**
	 * Delete account group.
	 *
	 * @param newAccount the new account
	 * @return the boolean
	 */
	public Boolean deleteAccountGroup(AccountGroupJPA newAccount);

	/**
	 * List account groups by user.
	 *
	 * @param userName the user name
	 * @return the collection
	 */
	public Collection<?> listAccountGroupsByUser(String userName);

	/**
	 * List accounts by account group.
	 *
	 * @param userName the user name
	 * @param accountGroupName the account group name
	 * @return the collection
	 */
	public Collection<?> listAccountsByAccountGroup(String userName,
			String accountGroupName);

	/**
	 * Update encrypted data.
	 *
	 * @param userName the user name
	 * @param newMasterPassword the new master password
	 * @return the boolean
	 */
	public Boolean updateEncryptedData(String userName, String newMasterPassword);

	/**
	 * Show account group.
	 *
	 * @param accountGroupName the account group name
	 * @return the account jpa
	 */
	public AccountJPA showAccountGroup(String accountGroupName);

	/**
	 * Show account group.
	 *
	 * @param id the id
	 * @return the account jpa
	 */
	public AccountJPA showAccountGroup(int id);

	/**
	 * Show account by account group.
	 *
	 * @param groupName the group name
	 * @param accountName the account name
	 * @return the account jpa
	 */
	public AccountJPA showAccountByAccountGroup(String groupName,
			String accountName);

	/**
	 * Adds the additional account info.
	 *
	 * @param accountInfo the account info
	 * @return the additional account info jpa
	 */
	public AdditionalAccountInfoJPA addAdditionalAccountInfo(
			AdditionalAccountInfoJPA accountInfo);

	/**
	 * Delete additional account info.
	 *
	 * @param accountInfo the account info
	 * @return the boolean
	 */
	public Boolean deleteAdditionalAccountInfo(
			AdditionalAccountInfoJPA accountInfo);

	/**
	 * List additional account info jpa by account.
	 *
	 * @param idAccount the id account
	 * @return the collection
	 */
	public Collection<?> listAdditionalAccountInfoJPAByAccount(int idAccount);

	/**
	 * Save additional account info jpa.
	 *
	 * @param newAccountInfo the new account info
	 * @return the additional account info jpa
	 */
	public AdditionalAccountInfoJPA saveAdditionalAccountInfoJPA(
			AdditionalAccountInfoJPA newAccountInfo);
}
