/** 
 * @author ngel Arias Romero. 
 * UOC - TFC SaveMeSafe 2015
 */
package ejb;

import javax.ejb.Remote;

import jpa.UserJPA;
import exception.CannotSendMailException;
import exception.CustomWrapperException;
import exception.UserNotFoundException;

// TODO: Auto-generated Javadoc
/**
 * Session EJB Remote Interfaces.
 */
@Remote
public interface UserFacadeRemote {

	/**
	 * Remotely invoked method.
	 *
	 * @param newUser            the new user
	 * @return the user jpa
	 * @throws CustomWrapperException the custom wrapper exception
	 */
	public UserJPA addUser(UserJPA newUser) throws CustomWrapperException;

	/**
	 * Update user.
	 *
	 * @param currentUser
	 *            the current user
	 * @return the user jpa
	 * @throws Exception
	 *             the exception
	 */
	public UserJPA updateUser(UserJPA currentUser) throws Exception;

	/**
	 * Delete user.
	 *
	 * @param currentUser
	 *            the current user
	 * @return the boolean
	 * @throws Exception
	 *             the exception
	 */
	public Boolean deleteUser(UserJPA currentUser) throws Exception;

	/**
	 * Do login.
	 *
	 * @param user            the user
	 * @param pass            the pass
	 * @return the user jpa
	 * @throws CustomWrapperException the custom wrapper exception
	 */
	public UserJPA doLogin(String user, String pass)
			throws CustomWrapperException;

	/**
	 * Gets the user by action token.
	 *
	 * @param actionToken
	 *            the action token
	 * @return the user by action token
	 * @throws UserNotFoundException
	 *             the user not found exception
	 */
	public UserJPA getUserByActionToken(String actionToken)
			throws UserNotFoundException;

	/**
	 * Gets the user by identifier.
	 *
	 * @param userIdentifier
	 *            the user identifier
	 * @return the user by identifier
	 * @throws UserNotFoundException
	 *             the user not found exception
	 */
	public UserJPA getUserByIdentifier(String userIdentifier)
			throws UserNotFoundException;

	// private void sendEmail(Email email);
	/**
	 * Send activation mail.
	 *
	 * @param user
	 *            the user
	 * @param serverString
	 *            the server string
	 * @throws CannotSendMailException
	 *             the cannot send mail exception
	 */
	public void sendActivationMail(UserJPA user, String serverString)
			throws CannotSendMailException;

	/**
	 * Activate user.
	 *
	 * @param user
	 *            the user
	 * @return the user jpa
	 * @throws UserNotFoundException
	 *             the user not found exception
	 */
	public UserJPA activateUser(UserJPA user) throws UserNotFoundException;

	/**
	 * Send password reset mail.
	 *
	 * @param user
	 *            the user
	 * @param serverString
	 *            the server string
	 * @throws CannotSendMailException
	 *             the cannot send mail exception
	 */
	public void sendPasswordResetMail(UserJPA user, String serverString)
			throws CannotSendMailException;

	/**
	 * Reset password.
	 *
	 * @param user
	 *            the user
	 * @return the user jpa
	 * @throws UserNotFoundException
	 *             the user not found exception
	 */
	public UserJPA resetPassword(UserJPA user) throws UserNotFoundException;

	/**
	 * Initiate reset password.
	 *
	 * @param user
	 *            the user
	 * @return the user jpa
	 */
	public UserJPA initiateResetPassword(UserJPA user);
}
