/** 
 * @author ngel Arias Romero. 
 * UOC - TFC SaveMeSafe 2015
 */
package jpa;

import java.io.Serializable;
import java.util.Collection;

import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.EntityListeners;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;
import javax.persistence.Table;

// TODO: Auto-generated Javadoc
/**
 * JPA Class AccountGroupJPA.
 */
@Entity
@Table(name = "accountgroup", schema = "savemesafe")
/**
 * La clase CryptoConverterAccountGroupListener.class ser invocada cuando se instance esta entidad 
 * y permite cifrar y descifrar los datos requeridos de forma transparente.
 */
@EntityListeners(CryptoConverterAccountGroupListener.class)
public class AccountGroupJPA implements Serializable {

	// @Convert(converter = CryptoConverter.class)

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 1L;

	/** The id. */
	@Id
	@GeneratedValue(strategy = GenerationType.IDENTITY)
	private int id;
	
	/** The name. */
	private String name;
	
	/** The description. */
	private String description;

	/** The owner user. */
	@ManyToOne()
	@JoinColumn(name = "ownerUser")
	private UserJPA ownerUser;

	/** The accounts. */
	@OneToMany(mappedBy = "ownerGroup", fetch = FetchType.EAGER, cascade = { CascadeType.REMOVE })
	private Collection<AccountJPA> accounts;

	/**
	 * Class constructor methods.
	 */
	public AccountGroupJPA() {
		super();
	}

	/**
	 * Instantiates a new account group jpa.
	 *
	 * @param id the id
	 * @param groupName the group name
	 * @param ownerUser the owner user
	 * @param accounts the accounts
	 */
	public AccountGroupJPA(int id, String groupName, UserJPA ownerUser,
			Collection<AccountJPA> accounts) {
		super();
		this.id = id;
		this.name = groupName;
		this.ownerUser = ownerUser;
		this.accounts = accounts;
	}

	/**
	 * Gets the id.
	 *
	 * @return the id
	 */
	public int getId() {
		// System.out.println("AccountGroupJPA.getId = " + id);
		return id;
	}

	/**
	 * Sets the id.
	 *
	 * @param id the new id
	 */
	public void setId(int id) {
		this.id = id;
	}

	/**
	 * Methods get/set the fields of database Id Primary Key field.
	 *
	 * @return the name
	 */

	public String getName() {
		return name;
	}

	/**
	 * Sets the name.
	 *
	 * @param groupName the new name
	 */
	public void setName(String groupName) {
		this.name = groupName;
	}

	/**
	 * Gets the description.
	 *
	 * @return the description
	 */
	public String getDescription() {
		return description;
	}

	/**
	 * Sets the description.
	 *
	 * @param description the new description
	 */
	public void setDescription(String description) {
		this.description = description;
	}

	/**
	 * Methods get/set persistent relationships.
	 *
	 * @return the user
	 */
	public UserJPA getUser() {
		return ownerUser;
	}

	/**
	 * Sets the user.
	 *
	 * @param ownerUser the new user
	 */
	public void setUser(UserJPA ownerUser) {
		this.ownerUser = ownerUser;
	}

	/**
	 * Gets the accounts.
	 *
	 * @return the accounts
	 */
	public Collection<AccountJPA> getAccounts() {
		return accounts;
	}

	/**
	 * Sets the accounts.
	 *
	 * @param accounts the new accounts
	 */
	public void setAccounts(Collection<AccountJPA> accounts) {
		this.accounts = accounts;
	}
}
