/** 
 * @author ngel Arias Romero. 
 * UOC - TFC SaveMeSafe 2015
 */
package jpa;

import java.io.Serializable;
import java.util.Collection;
import java.util.Date;

import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.EntityListeners;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;
import javax.persistence.Table;

// TODO: Auto-generated Javadoc
/**
 * JPA Class AccountJPA.
 */
@Entity
@Table(name = "account", schema = "savemesafe")
/**
 * La clase CryptoConverterAccountListener.class ser invocada cuando se instance esta entidad 
 * y permite cifrar y descifrar los datos requeridos de forma transparente.
 */
@EntityListeners(CryptoConverterAccountListener.class)
public class AccountJPA implements Serializable {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 1L;

	/** The id. */
	@Id
	@GeneratedValue(strategy = GenerationType.IDENTITY)
	private int id;

	/** The name. */
	private String name;
	
	/** The description. */
	private String description;

	/** The user name. */
	private String userName;
	
	/** The user password. */
	private String userPassword;

	/** The user email. */
	private String userEmail;
	
	/** The urn access. */
	private String urnAccess;
	
	/** The expiration date. */
	private Date expirationDate;

	/** The owner group. */
	@ManyToOne
	@JoinColumn(name = "ownerGroup")
	private AccountGroupJPA ownerGroup;

	/** The additional info. */
	@OneToMany(mappedBy = "ownerAccount", fetch = FetchType.EAGER, cascade = { CascadeType.REMOVE })
	private Collection<AdditionalAccountInfoJPA> additionalInfo;

	/**
	 * Class constructor methods.
	 */
	public AccountJPA() {
		super();
	}

	/**
	 * Instantiates a new account jpa.
	 *
	 * @param id the id
	 * @param name the name
	 * @param description the description
	 * @param userName the user name
	 * @param userPassword the user password
	 * @param userEmail the user email
	 * @param urnAccess the urn access
	 * @param expirationDate the expiration date
	 * @param ownerGroup the owner group
	 */
	public AccountJPA(int id, String name, String description, String userName,
			String userPassword, String userEmail, String urnAccess,
			Date expirationDate, AccountGroupJPA ownerGroup) {
		super();
		this.id = id;
		this.name = name;
		this.description = description;
		this.userName = userName;
		this.userPassword = userPassword;
		this.userEmail = userEmail;
		this.urnAccess = urnAccess;
		this.expirationDate = expirationDate;
		this.ownerGroup = ownerGroup;
	}

	/**
	 * Gets the id.
	 *
	 * @return the id
	 */
	public int getId() {
		return id;
	}

	/**
	 * Sets the id.
	 *
	 * @param id the new id
	 */
	public void setId(int id) {
		this.id = id;
	}

	/**
	 * Methods get/set the fields of database.
	 *
	 * @return the name
	 */
	public String getName() {
		return name;
	}

	/**
	 * Sets the name.
	 *
	 * @param accountName the new name
	 */
	public void setName(String accountName) {
		this.name = accountName;
	}

	/**
	 * Gets the user name.
	 *
	 * @return the user name
	 */
	public String getUserName() {
		return userName;
	}

	/**
	 * Sets the user name.
	 *
	 * @param userName the new user name
	 */
	public void setUserName(String userName) {
		this.userName = userName;
	}

	/**
	 * Gets the user password.
	 *
	 * @return the user password
	 */
	public String getUserPassword() {
		return userPassword;
	}

	/**
	 * Sets the user password.
	 *
	 * @param userPassword the new user password
	 */
	public void setUserPassword(String userPassword) {
		this.userPassword = userPassword;
	}

	/**
	 * Gets the user email.
	 *
	 * @return the user email
	 */
	public String getUserEmail() {
		return userEmail;
	}

	/**
	 * Sets the user email.
	 *
	 * @param userEmail the new user email
	 */
	public void setUserEmail(String userEmail) {
		this.userEmail = userEmail;
	}

	/**
	 * Gets the urn access.
	 *
	 * @return the urn access
	 */
	public String getUrnAccess() {
		return urnAccess;
	}

	/**
	 * Sets the urn access.
	 *
	 * @param urnAccess the new urn access
	 */
	public void setUrnAccess(String urnAccess) {
		this.urnAccess = urnAccess;
	}

	/**
	 * Gets the description.
	 *
	 * @return the description
	 */
	public String getDescription() {
		return description;
	}

	/**
	 * Sets the description.
	 *
	 * @param description the new description
	 */
	public void setDescription(String description) {
		this.description = description;
	}

	/**
	 * Gets the expiration date.
	 *
	 * @return the expiration date
	 */
	public Date getExpirationDate() {
		return expirationDate;
	}

	/**
	 * Sets the expiration date.
	 *
	 * @param expirationDate the new expiration date
	 */
	public void setExpirationDate(Date expirationDate) {
		this.expirationDate = expirationDate;
	}

	/**
	 * Methods get/set persistent relationships.
	 *
	 * @return the owner group
	 */
	public AccountGroupJPA getOwnerGroup() {
		return ownerGroup;
	}

	/**
	 * Sets the owner group.
	 *
	 * @param ownerGroup the new owner group
	 */
	public void setOwnerGroup(AccountGroupJPA ownerGroup) {
		this.ownerGroup = ownerGroup;
	}

	/**
	 * Gets the additional info.
	 *
	 * @return the additional info
	 */
	public Collection<AdditionalAccountInfoJPA> getAdditionalInfo() {
		return additionalInfo;
	}

	/**
	 * Sets the additional info.
	 *
	 * @param additionalInfo the new additional info
	 */
	public void setAdditionalInfo(
			Collection<AdditionalAccountInfoJPA> additionalInfo) {
		this.additionalInfo = additionalInfo;
	}

}
