/** 
 * @author ngel Arias Romero. 
 * UOC - TFC SaveMeSafe 2015
 */
package jpa;

import javax.persistence.PostLoad;
import javax.persistence.PostPersist;
import javax.persistence.PostUpdate;
import javax.persistence.PrePersist;
import javax.persistence.PreUpdate;

import crypto.CustomCrypto;

// TODO: Auto-generated Javadoc
/**
 * The listener interface for receiving cryptoConverterAccountGroup events.
 * The class that is interested in processing a cryptoConverterAccountGroup
 * event implements this interface, and the object created
 * with that class is registered with a component using the
 * component's <code>addCryptoConverterAccountGroupListener<code> method. When
 * the cryptoConverterAccountGroup event occurs, that object's appropriate
 * method is invoked.
 *
 * @see CryptoConverterAccountGroupEvent
 */
public class CryptoConverterAccountGroupListener {

	/**
	 * Hashes the plainPassword of the user if set and stores it in password.
	 *
	 * @param group the group
	 */
	@PrePersist
	@PreUpdate
	private void encrypData(AccountGroupJPA group) {

		String encryptedPass = group.getUser().getPassword();

		try {

			group.setName(CustomCrypto.encrypt(encryptedPass, group.getName()));
			group.setDescription(CustomCrypto.encrypt(encryptedPass,
					group.getDescription()));

		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

	}

	/**
	 * Desencrypt data.
	 *
	 * @param group the group
	 */
	@PostLoad
	@PostUpdate
	@PostPersist
	private void desencryptData(AccountGroupJPA group) {

		String encryptedPass = group.getUser().getPassword();

		try {

			group.setName(CustomCrypto.decrypt(encryptedPass, group.getName()));
			group.setDescription(CustomCrypto.decrypt(encryptedPass,
					group.getDescription()));

		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

	}

}
