/** 
 * @author ngel Arias Romero. 
 * UOC - TFC SaveMeSafe 2015
 */

package jpa;

import javax.persistence.PostLoad;
import javax.persistence.PostPersist;
import javax.persistence.PostUpdate;
import javax.persistence.PrePersist;
import javax.persistence.PreUpdate;

import crypto.CustomCrypto;

// TODO: Auto-generated Javadoc
/**
 * The listener interface for receiving cryptoConverterAccount events.
 * The class that is interested in processing a cryptoConverterAccount
 * event implements this interface, and the object created
 * with that class is registered with a component using the
 * component's <code>addCryptoConverterAccountListener<code> method. When
 * the cryptoConverterAccount event occurs, that object's appropriate
 * method is invoked.
 *
 * @see CryptoConverterAccountEvent
 */
public class CryptoConverterAccountListener {

	/**
	 * Hashes the plainPassword of the user if set and stores it in password.
	 *
	 * @param account the account
	 */
	@PrePersist
	@PreUpdate
	private void encrypData(AccountJPA account) {

		String encryptedPass = account.getOwnerGroup().getUser().getPassword();

		try {

			account.setName(CustomCrypto.encrypt(encryptedPass,
					account.getName()));
			account.setUserPassword(CustomCrypto.encrypt(encryptedPass,
					account.getUserPassword()));
			account.setUserEmail(CustomCrypto.encrypt(encryptedPass,
					account.getUserEmail()));
			account.setDescription(CustomCrypto.encrypt(encryptedPass,
					account.getDescription()));

		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

	}

	/**
	 * Desencrypt data.
	 *
	 * @param account the account
	 */
	@PostLoad
	@PostUpdate
	@PostPersist
	private void desencryptData(AccountJPA account) {

		String encryptedPass = account.getOwnerGroup().getUser().getPassword();

		try {

			account.setName(CustomCrypto.decrypt(encryptedPass,
					account.getName()));
			account.setUserPassword(CustomCrypto.decrypt(encryptedPass,
					account.getUserPassword()));
			account.setUserEmail(CustomCrypto.decrypt(encryptedPass,
					account.getUserEmail()));
			account.setDescription(CustomCrypto.decrypt(encryptedPass,
					account.getDescription()));

		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

	}

}
