/** 
 * @author ngel Arias Romero. 
 * UOC - TFC SaveMeSafe 2015
 */

package jpa;

import javax.persistence.PostLoad;
import javax.persistence.PostPersist;
import javax.persistence.PostUpdate;
import javax.persistence.PrePersist;
import javax.persistence.PreUpdate;

import crypto.CustomCrypto;

// TODO: Auto-generated Javadoc
/**
 * The listener interface for receiving cryptoConverterAdditionalAccountInfo events.
 * The class that is interested in processing a cryptoConverterAdditionalAccountInfo
 * event implements this interface, and the object created
 * with that class is registered with a component using the
 * component's <code>addCryptoConverterAdditionalAccountInfoListener<code> method. When
 * the cryptoConverterAdditionalAccountInfo event occurs, that object's appropriate
 * method is invoked.
 *
 * @see CryptoConverterAdditionalAccountInfoEvent
 */
public class CryptoConverterAdditionalAccountInfoListener {

	/**
	 * Hashes the plainPassword of the user if set and stores it in password.
	 *
	 * @param info the info
	 */
	@PrePersist
	@PreUpdate
	private void encrypData(AdditionalAccountInfoJPA info) {

		String encryptedPass = info.getOwnerAccount().getOwnerGroup().getUser()
				.getPassword();

		try {

			info.setKey(CustomCrypto.encrypt(encryptedPass, info.getKey()));
			info.setValue(CustomCrypto.encrypt(encryptedPass, info.getValue()));

		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

	}

	/**
	 * Desencrypt data.
	 *
	 * @param info the info
	 */
	@PostLoad
	@PostUpdate
	@PostPersist
	private void desencryptData(AdditionalAccountInfoJPA info) {

		String encryptedPass = info.getOwnerAccount().getOwnerGroup().getUser()
				.getPassword();

		try {

			info.setKey(CustomCrypto.decrypt(encryptedPass, info.getKey()));
			info.setValue(CustomCrypto.decrypt(encryptedPass, info.getValue()));

		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

	}

}
