/** 
 * @author ngel Arias Romero. 
 * UOC - TFC SaveMeSafe 2015
 */

package jpa;

import java.io.Serializable;
//import java.sql.Date;
import java.util.Collection;
import java.util.Date;

import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.OneToMany;
import javax.persistence.PrePersist;
import javax.persistence.PreUpdate;
import javax.persistence.Table;
import javax.persistence.Transient;
import javax.validation.constraints.Size;

/*
 * 
 *  Work arround para hacer fetch de usuarios y grupos y poder acceder como una lista directamente
 *  Se ha copiado el jar de hibernate en D:\DatosUsuario\jboss-as-7.1.1.Final\modules\hibernate-core-4.0.1.Final.jar
 *  
 *  
 * */
import org.hibernate.annotations.Fetch;
import org.hibernate.annotations.FetchMode;

// TODO: Auto-generated Javadoc
/**
 * JPA Class UsuarioJPA.
 */
@Entity
@Table(name = "user", schema = "savemesafe")
public class UserJPA implements Serializable {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 1L;

	/**
	 * Id unique for the user.
	 */
	@Id
	@GeneratedValue(strategy = GenerationType.IDENTITY)
	private int id;

	// @Size(min = 4, max = 16, message =
	// "El valor '${validatedValue}' debe ser entre {min} y {max} caracteres")
	/** The name. */
	@Size(min = 4, max = 16)
	@Column(unique = true)
	private String name;

	/**
	 * Password hash of the user.
	 */

	private String password;

	/**
	 * Password of the user.
	 */
	@Transient
	@Size(min = 6, max = 32)
	private String plainPassword;

	/**
	 * E-Mail of the user.
	 */
	// @Email
	@Size(min = 3, max = 254)
	@Column(unique = true, length = 64)
	private String email;

	/*
	 * Number of access fails
	 */
	/** The try number. */
	private int tryNumber;

	/*
	 * For check if a user is blocked or not. May be blocked because still not
	 * activate or spends all tries.
	 */
	/** The blocked. */
	private boolean blocked;

	/**
	 * Token required to be allowed to execute specific actions on the user
	 * (e.g. activate a created user) (After a token is used one time it should
	 * be deleted)
	 */
	@Column(unique = true)
	private String actionToken;

	/*
	 * Date of creation user
	 */
	/** The creation date. */
	private Date creationDate;

	/*
	 * Last login of the user into the app
	 */
	/** The last login date. */
	private Date lastLoginDate;

	/*
	 * Relation with AccountGroupJPA
	 */
	/** The groups. */
	@OneToMany(mappedBy = "ownerUser", fetch = FetchType.EAGER, cascade = { CascadeType.REMOVE })
	@Fetch(FetchMode.SELECT)
	private Collection<AccountGroupJPA> groups;

	/**
	 * Class constructor methods.
	 */
	public UserJPA() {
		super();
	}

	/**
	 * Fills the date created before persisting the object.
	 */
	@PrePersist
	protected void onCreate() {
		creationDate = new Date();
	}

	/**
	 * Fills the date for update before persisting the object.
	 */
	@PreUpdate
	protected void onUpdate() {
		creationDate = new Date();
	}

	/**
	 * Instantiates a new user jpa.
	 *
	 * @param id the id
	 * @param name the name
	 * @param password the password
	 * @param plainPassword the plain password
	 * @param email the email
	 * @param actionToken the action token
	 * @param tryNumber the try number
	 * @param blocked the blocked
	 * @param creationDate the creation date
	 * @param lastLoginDate the last login date
	 * @param groups the groups
	 */
	public UserJPA(int id, String name, String password, String plainPassword,
			String email, String actionToken, int tryNumber, boolean blocked,
			Date creationDate, Date lastLoginDate,
			Collection<AccountGroupJPA> groups) {
		super();
		this.id = id;
		this.name = name;
		this.password = password;
		this.plainPassword = plainPassword;
		this.email = email;
		this.actionToken = actionToken;
		this.tryNumber = tryNumber;
		this.blocked = blocked;
		this.creationDate = creationDate;
		this.lastLoginDate = lastLoginDate;
		this.groups = groups;
	}

	/**
	 * Methods get/set the fields of database.
	 *
	 * @return the id
	 */
	public int getId() {
		return id;
	}

	/**
	 * Sets the id.
	 *
	 * @param id the new id
	 */
	public void setId(int id) {
		this.id = id;
	}

	/**
	 * Gets the name.
	 *
	 * @return the name
	 */
	public String getName() {
		return name;
	}

	/**
	 * Sets the name.
	 *
	 * @param name the new name
	 */
	public void setName(String name) {
		this.name = name;
	}

	/**
	 * Gets the password.
	 *
	 * @return the password
	 */
	public String getPassword() {
		return password;
	}

	/**
	 * Sets the password.
	 *
	 * @param password the new password
	 */
	public void setPassword(String password) {
		this.password = password;
	}

	/**
	 * Gets the plain password.
	 *
	 * @return the plain password
	 */
	public String getPlainPassword() {
		return plainPassword;
	}

	/**
	 * Sets the plain password.
	 *
	 * @param plainPassword the new plain password
	 */
	public void setPlainPassword(String plainPassword) {
		this.plainPassword = plainPassword;
	}

	/**
	 * Gets the action token.
	 *
	 * @return the action token
	 */
	public String getActionToken() {
		return actionToken;
	}

	/**
	 * Sets the action token.
	 *
	 * @param actionToken the new action token
	 */
	public void setActionToken(String actionToken) {
		this.actionToken = actionToken;
	}

	/**
	 * Gets the email.
	 *
	 * @return the email
	 */
	public String getEmail() {
		return email;
	}

	/**
	 * Sets the email.
	 *
	 * @param email the new email
	 */
	public void setEmail(String email) {
		this.email = email;
	}

	/**
	 * Gets the try number.
	 *
	 * @return the try number
	 */
	public int getTryNumber() {
		return tryNumber;
	}

	/**
	 * Sets the try number.
	 *
	 * @param tryNumber the new try number
	 */
	public void setTryNumber(int tryNumber) {
		this.tryNumber = tryNumber;
	}

	/**
	 * Checks if is blocked.
	 *
	 * @return true, if is blocked
	 */
	public boolean isBlocked() {
		return blocked;
	}

	/**
	 * Sets the blocked.
	 *
	 * @param blocked the new blocked
	 */
	public void setBlocked(boolean blocked) {
		this.blocked = blocked;
	}

	/**
	 * Gets the creation date.
	 *
	 * @return the creation date
	 */
	public Date getCreationDate() {
		return creationDate;
	}

	/**
	 * Sets the creation date.
	 *
	 * @param creationDate the new creation date
	 */
	public void setCreationDate(Date creationDate) {
		this.creationDate = creationDate;
	}

	/**
	 * Gets the last login date.
	 *
	 * @return the last login date
	 */
	public Date getLastLoginDate() {
		return lastLoginDate;
	}

	/**
	 * Sets the last login date.
	 *
	 * @param lastLoginDate the new last login date
	 */
	public void setLastLoginDate(Date lastLoginDate) {
		this.lastLoginDate = lastLoginDate;
	}

	/**
	 * Methods get/set persistent relationships.
	 *
	 * @return the groups
	 */
	public Collection<AccountGroupJPA> getGroups() {
		return groups;
	}

	/**
	 * Sets the groups.
	 *
	 * @param groups the new groups
	 */
	public void setGroups(Collection<AccountGroupJPA> groups) {
		this.groups = groups;
	}
}
