/** 
 * @author ngel Arias Romero. 
 * UOC - TFC SaveMeSafe 2015
 */

package managedbean;

import java.io.Serializable;

import javax.ejb.EJB;
import javax.faces.bean.ManagedBean;
import javax.faces.bean.ViewScoped;
import javax.faces.context.FacesContext;
import javax.servlet.http.HttpServletRequest;

import jpa.UserJPA;
import ejb.UserFacadeRemote;

// TODO: Auto-generated Javadoc
/**
 * View bean to add a new user.
 */
@ManagedBean(name = "activateUser")
@ViewScoped
public class ActivateUserView implements Serializable {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 1L;

	/** The login remote. */
	@EJB
	private UserFacadeRemote loginRemote;

	/** The activate user successful. */
	private boolean activateUserSuccessful = false;

	/** The user. */
	private UserJPA user;

	/**
	 * Reads the action token and processes it.
	 */
	public void processActionToken() {
		if (!activateUserSuccessful) {
			HttpServletRequest request = (HttpServletRequest) FacesContext
					.getCurrentInstance().getExternalContext().getRequest();
			String actionToken = request.getParameter("uid");

			try {
				user = loginRemote.getUserByActionToken(actionToken);
			} catch (Exception e) {
				FacesMessagesWrapper.addError("Action token not valid.");
				user = null;
			}
		}
	}

	/**
	 * Method responsible for triggering the activation of an already created
	 * user.
	 */
	public void activateUser() {
		// Fetch the token from URL request

		if (user != null) {
			try {
				user = loginRemote.activateUser(user);
				activateUserSuccessful = true;
			} catch (Exception e) {
				FacesMessagesWrapper.addError("User could not be found.");
				activateUserSuccessful = false;
			}
		} else {
			activateUserSuccessful = false;
		}

	}

	// ---------- getter/setter ----------

	/**
	 * Gets the user.
	 *
	 * @return the user
	 */
	public UserJPA getUser() {
		return user;
	}

	/**
	 * Checks if is activate user successful.
	 *
	 * @return true, if is activate user successful
	 */
	public boolean isActivateUserSuccessful() {
		return activateUserSuccessful;
	}

	/**
	 * Sets the activate user successful.
	 *
	 * @param activateUserSuccessful the new activate user successful
	 */
	public void setActivateUserSuccessful(boolean activateUserSuccessful) {
		this.activateUserSuccessful = activateUserSuccessful;
	}

	/**
	 * Sets the user.
	 *
	 * @param user the new user
	 */
	public void setUser(UserJPA user) {
		this.user = user;
	}
}