/** 
 * @author ngel Arias Romero. 
 * UOC - TFC SaveMeSafe 2015
 */

package managedbean;

import java.io.Serializable;
import java.util.Collection;
import java.util.Properties;

import javax.annotation.PostConstruct;
import javax.ejb.EJB;
import javax.faces.bean.ManagedBean;
import javax.faces.bean.ViewScoped;
import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;

import jpa.AccountJPA;
import jpa.AdditionalAccountInfoJPA;
import ejb.AccountsFacadeRemote;

// TODO: Auto-generated Javadoc
/**
 * The Class CollectorView.
 */
@ManagedBean
@ViewScoped
public class CollectorView implements Serializable {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 1L;

	/** The account dyn info. */
	private AdditionalAccountInfoJPA accountDynInfo;

	/** The account dyn info list. */
	private Collection<AdditionalAccountInfoJPA> accountDynInfoList;

	/** The current account. */
	private AccountJPA currentAccount;

	/** The account remote. */
	@EJB
	private AccountsFacadeRemote accountRemote;

	/**
	 * Inits the.
	 */
	@PostConstruct
	public void init() {

		accountDynInfo = new AdditionalAccountInfoJPA();

		// accountDynInfoList = new ArrayList<AdditionalAccountInfoJPA>();

		Properties props = System.getProperties();
		Context ctx;
		try {
			ctx = new InitialContext(props);
			accountRemote = (AccountsFacadeRemote) ctx
					.lookup("java:app/savemesafeEJB/AccountsFacadeBean!ejb.AccountsFacadeRemote");
		} catch (NamingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	/**
	 * Delete.
	 *
	 * @param accountInfo the account info
	 */
	public void delete(AdditionalAccountInfoJPA accountInfo) {
		accountInfo.setOwnerAccount(currentAccount);
		accountRemote.deleteAdditionalAccountInfo(accountInfo);
	}

	/**
	 * Sets the current account.
	 *
	 * @param account the new current account
	 */
	@SuppressWarnings("unchecked")
	public void setCurrentAccount(AccountJPA account) {

		if (account == null)
			return;

		currentAccount = account;
		accountDynInfoList = (Collection<AdditionalAccountInfoJPA>) accountRemote
				.listAdditionalAccountInfoJPAByAccount(currentAccount.getId());
	}

	/**
	 * Creates the new.
	 */
	public void createNew() {

		if (accountDynInfo.getKey() != null
				&& accountDynInfo.getValue() != null) {
			if (currentAccount != null && currentAccount.getId() != 0) {
				accountDynInfo.setOwnerAccount(currentAccount);
				accountRemote.addAdditionalAccountInfo(accountDynInfo);
				accountDynInfo = new AdditionalAccountInfoJPA();
			} else {
				FacesMessagesWrapper
						.addError("No se ha guardado la cuenta actual");
			}

		}
	}

	/**
	 * Gets the account dyn info.
	 *
	 * @return the account dyn info
	 */
	public AdditionalAccountInfoJPA getAccountDynInfo() {
		return accountDynInfo;
	}

	/**
	 * Sets the account dyn info.
	 *
	 * @param accountDynInfo the new account dyn info
	 */
	public void setAccountDynInfo(AdditionalAccountInfoJPA accountDynInfo) {
		this.accountDynInfo = accountDynInfo;
	}

	/**
	 * Gets the account dyn info list.
	 *
	 * @return the account dyn info list
	 */
	public Collection<AdditionalAccountInfoJPA> getAccountDynInfoList() {
		return accountDynInfoList;
	}

	/**
	 * Sets the account dyn info list.
	 *
	 * @param accountDynInfoList the new account dyn info list
	 */
	public void setAccountDynInfoList(
			Collection<AdditionalAccountInfoJPA> accountDynInfoList) {
		this.accountDynInfoList = accountDynInfoList;
	}

}
