/** 
 * @author ngel Arias Romero. 
 * UOC - TFC SaveMeSafe 2015
 */

package managedbean;

import java.io.Serializable;
import java.util.Properties;

import javax.annotation.PostConstruct;
import javax.ejb.EJB;
import javax.faces.bean.ManagedBean;
import javax.faces.bean.ViewScoped;
import javax.faces.context.FacesContext;
import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.servlet.http.HttpServletRequest;

import jpa.UserJPA;
import ejb.UserFacadeRemote;
import exception.CustomWrapperException;

// TODO: Auto-generated Javadoc
/**
 * The Class CreateUserView.
 */
@ManagedBean(name = "createUser")
@ViewScoped
public class CreateUserView implements Serializable {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 1L;

	/** The user. */
	private UserJPA user;

	/** The login remote. */
	@EJB
	private UserFacadeRemote loginRemote;

	/** The add user successful. */
	private boolean addUserSuccessful;

	/**
	 * Instantiates a new creates the user view.
	 *
	 * @throws Exception the exception
	 */
	public CreateUserView() throws Exception {
		this.init();
	}

	/**
	 * Adds the user.
	 *
	 * @return the string
	 */
	public String addUser() {

		try {
			if ((user = loginRemote.addUser(user)) != null) {
				addUserSuccessful = true;
				HttpServletRequest request = (HttpServletRequest) FacesContext
						.getCurrentInstance().getExternalContext().getRequest();
				String serverString = request.getServerName() + ":"
						+ request.getServerPort();
				try {
					loginRemote.sendActivationMail(user, serverString);
					addUserSuccessful = true;
				} catch (Exception e) {
					FacesMessagesWrapper
							.addError("Could not send activation mail.");
					addUserSuccessful = false;
				}
				return null;// "login";
			}
		} catch (CustomWrapperException e) {
			// TODO Auto-generated catch block
			FacesMessagesWrapper.addError(e.getMessage());
			addUserSuccessful = false;
		}
		return "registration";
	}

	/**
	 * Initializes the instance for use.
	 */
	@PostConstruct
	public void init() {

		user = new UserJPA();

		try {
			addUserSuccessful = false;

			Properties props = System.getProperties();
			Context ctx = new InitialContext(props);

			loginRemote = (UserFacadeRemote) ctx
					.lookup("java:app/savemesafeEJB/UserFacadeBean!ejb.UserFacadeRemote");
		} catch (NamingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();

			throw new RuntimeException(e);
		}
	}

	/**
	 * Checks if is adds the user successful.
	 *
	 * @return true, if is adds the user successful
	 */
	public boolean isAddUserSuccessful() {
		return addUserSuccessful;
	}

	/**
	 * Sets the adds the user successful.
	 *
	 * @param addUserSuccessful the new adds the user successful
	 */
	public void setAddUserSuccessful(boolean addUserSuccessful) {
		this.addUserSuccessful = addUserSuccessful;
	}

	/**
	 * Gets the user.
	 *
	 * @return the user
	 */
	public UserJPA getUser() {
		return user;
	}

	/**
	 * Sets the user.
	 *
	 * @param user the new user
	 */
	public void setUser(UserJPA user) {
		this.user = user;
	}

}