/** 
 * @author ngel Arias Romero. 
 * UOC - TFC SaveMeSafe 2015
 */

package managedbean;

import java.io.Serializable;

import javax.faces.application.FacesMessage;
import javax.faces.context.FacesContext;

// TODO: Auto-generated Javadoc
/**
 * Helper class to simplify the output of FacesMessages It results in the
 * creation of an additional object, but at the same time it allows us to unit
 * test backing beans.
 * 
 * @author ngel Arias Romero
 */

public class FacesMessagesWrapper implements Serializable {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 1L;

	/**
	 * Add Faces Info-Message.
	 * 
	 * @param message
	 *            Message to publish.
	 */
	public static void addInfo(String message) {
		addMessage(FacesMessage.SEVERITY_INFO, message, "");
	}

	/**
	 * Adds the info.
	 *
	 * @param message the message
	 * @param detailedInfo the detailed info
	 */
	public static void addInfo(String message, String detailedInfo) {
		addMessage(FacesMessage.SEVERITY_INFO, message, detailedInfo);
	}

	/**
	 * Add Faces Error-Message.
	 * 
	 * @param message
	 *            Message to publish.
	 */
	public static void addError(final String message) {
		addMessage(FacesMessage.SEVERITY_ERROR, message, "");
	}

	/**
	 * Add Faces Error-Message for a specific component.
	 * 
	 * @param message
	 *            Message to publish.
	 * @param detailedInfo
	 *            Detail to publish.
	 */
	public static void addError(String message, String detailedInfo) {
		addMessage(FacesMessage.SEVERITY_ERROR, message, detailedInfo);
	}

	/**
	 * Add Faces Error-Message.
	 *
	 * @param message            Message to publish.
	 * @param detailedInfo the detailed info
	 */
	public static void addWarning(String message, String detailedInfo) {
		addMessage(FacesMessage.SEVERITY_WARN, message, detailedInfo);
	}

	/**
	 * Adds the message.
	 *
	 * @param severity the severity
	 * @param message the message
	 * @param detailedInfo the detailed info
	 */
	private static void addMessage(final FacesMessage.Severity severity,
			final String message, final String detailedInfo) {
		FacesContext.getCurrentInstance().addMessage(null,
				new FacesMessage(severity, message, detailedInfo));
	}
}