/** 
 * @author ngel Arias Romero. 
 * UOC - TFC SaveMeSafe 2015
 */

package managedbean;

import java.io.Serializable;

import javax.annotation.PostConstruct;
import javax.ejb.EJB;
import javax.faces.bean.ManagedBean;
import javax.faces.bean.ViewScoped;
import javax.faces.context.FacesContext;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.servlet.http.HttpServletRequest;

import jpa.UserJPA;
import ejb.UserFacadeRemote;
import exception.CannotSendMailException;
import exception.UserNotFoundException;

// TODO: Auto-generated Javadoc
/**
 * Viewbean to add a new user.
 */
@ManagedBean(name = "forgotPassword")
@ViewScoped
public class ForgotPasswordView implements Serializable {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = -6437185754610418284L;

	/** The login remote. */
	@EJB
	private UserFacadeRemote loginRemote;

	/** The user identifier. */
	private String userIdentifier;

	/** The email sended. */
	private boolean emailSended = false;

	/**
	 * Initializes the instance for use.
	 */
	@PostConstruct
	public void init() {
		try {
			loginRemote = (UserFacadeRemote) new InitialContext(
					System.getProperties())
					.lookup("java:app/savemesafeEJB/UserFacadeBean!ejb.UserFacadeRemote");
		} catch (NamingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();

			throw new RuntimeException(e);
		}
	}

	/**
	 * Resets the password of the user identified by userIdentifier.
	 */
	public void resetPassword() {
		HttpServletRequest request = (HttpServletRequest) FacesContext
				.getCurrentInstance().getExternalContext().getRequest();
		String serverString = request.getServerName() + ":"
				+ request.getServerPort();

		try {
			UserJPA user = loginRemote.getUserByIdentifier(userIdentifier);
			UserJPA updatedUser = loginRemote.initiateResetPassword(user);
			loginRemote.sendPasswordResetMail(updatedUser, serverString);
			emailSended = true;
		} catch (UserNotFoundException exc) {
			FacesMessagesWrapper
					.addError("No se ha encontrado el usuario con los datos indicados.");
		} catch (CannotSendMailException e) {
			FacesMessagesWrapper.addError("Error enviado correo electrnico.");
		}

	}

	// ---------- getter/setter ----------
	/**
	 * Gets the user identifier.
	 *
	 * @return the user identifier
	 */
	public String getUserIdentifier() {
		return userIdentifier;
	}

	/**
	 * Sets the user identifier.
	 *
	 * @param userIdentifier the new user identifier
	 */
	public void setUserIdentifier(String userIdentifier) {
		this.userIdentifier = userIdentifier;
	}

	/**
	 * Checks if is email sended.
	 *
	 * @return true, if is email sended
	 */
	public boolean isEmailSended() {
		return emailSended;
	}

	/**
	 * Sets the email sended.
	 *
	 * @param emailSended the new email sended
	 */
	public void setEmailSended(boolean emailSended) {
		this.emailSended = emailSended;
	}
}