/** 
 * @author ngel Arias Romero. 
 * UOC - TFC SaveMeSafe 2015
 */

package managedbean;

import java.io.Serializable;

import javax.annotation.PostConstruct;
import javax.ejb.EJB;
import javax.faces.bean.ManagedBean;
import javax.faces.bean.SessionScoped;
import javax.faces.context.FacesContext;
import javax.naming.InitialContext;
import javax.naming.NamingException;

import jpa.UserJPA;
import ejb.UserFacadeRemote;
import exception.CustomWrapperException;

// TODO: Auto-generated Javadoc
/**
 * The Class LoginUserView.
 */
@ManagedBean(name = "loginUser")
@SessionScoped
/**
 *
 * @author User
 */
public class LoginUserView implements Serializable {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 1L;

	/** The current user. */
	private UserJPA currentUser = null;

	/** The user name. */
	private String userName;
	
	/** The user plain text password. */
	private String userPlainTextPassword;

	/** The login remote. */
	@EJB
	private UserFacadeRemote loginRemote;

	/**
	 * Instantiates a new login user view.
	 *
	 * @throws Exception the exception
	 */
	public LoginUserView() throws Exception {
		this.init();
	}

	/**
	 * Gets the user name.
	 *
	 * @return the user name
	 */
	public String getUserName() {
		return userName;
	}

	/**
	 * Sets the user name.
	 *
	 * @param userName the new user name
	 */
	public void setUserName(String userName) {
		this.userName = userName;
	}

	/**
	 * Gets the user password.
	 *
	 * @return the user password
	 */
	public String getUserPassword() {
		return userPlainTextPassword;
	}

	/**
	 * Sets the user password.
	 *
	 * @param userPassword the new user password
	 */
	public void setUserPassword(String userPassword) {
		this.userPlainTextPassword = userPassword;
	}

	/**
	 * Gets the current user.
	 *
	 * @return the current user
	 */
	public UserJPA getCurrentUser() {
		return currentUser;
	}

	/**
	 * Sets the current user.
	 *
	 * @param currentUser the new current user
	 */
	public void setCurrentUser(UserJPA currentUser) {
		this.currentUser = currentUser;
	}

	/**
	 * Login.
	 *
	 * @return the string
	 */
	public String login() {

		try {

			currentUser = loginRemote.doLogin(userName, userPlainTextPassword);

			if (currentUser != null) {
				return "/secured/home?faces-redirect=true";
			} else {

				FacesMessagesWrapper
						.addError("Datos de acceso incorrectos", "");

				return (userName = userPlainTextPassword = null);
			}
		} catch (CustomWrapperException e) {
			userName = userPlainTextPassword = null;
			currentUser = null;

			FacesMessagesWrapper.addError("Datos de acceso incorrectos",
					e.getMessage());

			return null;

		}
	}

	/**
	 * Logout.
	 *
	 * @return the string
	 */
	public String logout() {
		userName = userPlainTextPassword = null;
		currentUser = null;
		FacesContext.getCurrentInstance().getExternalContext()
				.invalidateSession();

		return "/public/login?faces-redirect=true";
	}

	/**
	 * Checks if is logged in.
	 *
	 * @return true, if is logged in
	 */
	public boolean isLoggedIn() {
		return currentUser != null;
	}

	/**
	 * Initializes the instance for use.
	 */
	@PostConstruct
	public void init() {
		try {
			loginRemote = (UserFacadeRemote) new InitialContext(
					System.getProperties())
					.lookup("java:app/savemesafeEJB/UserFacadeBean!ejb.UserFacadeRemote");
		} catch (NamingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();

			throw new RuntimeException(e);
		}
	}
}