/** 
 * @author ngel Arias Romero. 
 * UOC - TFC SaveMeSafe 2015
 */

package managedbean;

import java.io.Serializable;

import javax.annotation.PostConstruct;
import javax.ejb.EJB;
import javax.faces.bean.ManagedBean;
import javax.faces.bean.ViewScoped;
import javax.faces.context.FacesContext;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.servlet.http.HttpServletRequest;

import jpa.UserJPA;
import ejb.AccountsFacadeRemote;
import ejb.UserFacadeRemote;
import exception.UserNotFoundException;

// TODO: Auto-generated Javadoc
/**
 * View bean to add a new user.
 */
@ManagedBean(name = "resetPassword")
@ViewScoped
public class ResetPasswordView implements Serializable {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 7286469733954451382L;

	/** The login remote. */
	@EJB
	private UserFacadeRemote loginRemote;

	/** The accounts remote. */
	@EJB
	private AccountsFacadeRemote accountsRemote;

	/** The password reset successful. */
	private boolean passwordResetSuccessful = false;

	/** The user. */
	private UserJPA user;

	/**
	 * Inits the.
	 */
	@PostConstruct
	public void init() {
		try {
			loginRemote = (UserFacadeRemote) new InitialContext(
					System.getProperties())
					.lookup("java:app/savemesafeEJB/UserFacadeBean!ejb.UserFacadeRemote");

			accountsRemote = (AccountsFacadeRemote) new InitialContext(
					System.getProperties())
					.lookup("java:app/savemesafeEJB/AccountsFacadeBean!ejb.AccountsFacadeRemote");

		} catch (NamingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();

			throw new RuntimeException(e);
		}
	}

	/**
	 * Reads the action token and processes it.
	 */
	public void processActionToken() {
		if (!passwordResetSuccessful) {
			HttpServletRequest request = (HttpServletRequest) FacesContext
					.getCurrentInstance().getExternalContext().getRequest();
			String actionToken = request.getParameter("uid");

			try {
				user = loginRemote.getUserByActionToken(actionToken);
			} catch (UserNotFoundException e) {
				// No mostramos ventana con mensaje de error. La pgina muestra
				// el texto indicando un problema con el enlace.
				user = null;
			}
		}
	}

	/**
	 * Resets the password of the user identified by userIdentifier.
	 */
	public void resetPassword() {
		if (user != null) {
			try {
				user = loginRemote.resetPassword(user);
				accountsRemote.updateEncryptedData(user.getName(),
						user.getPassword());
				passwordResetSuccessful = true;
			} catch (Exception e) {
				FacesMessagesWrapper.addError("Could not find user.");
				passwordResetSuccessful = false;
			}
		} else {
			passwordResetSuccessful = false;
		}
	}

	// ---------- getter/setter ----------

	/**
	 * Checks if is password reset successful.
	 *
	 * @return true, if is password reset successful
	 */
	public boolean isPasswordResetSuccessful() {
		return passwordResetSuccessful;
	}

	/**
	 * Sets the password reset successful.
	 *
	 * @param passwordResetSuccessful the new password reset successful
	 */
	public void setPasswordResetSuccessful(boolean passwordResetSuccessful) {
		this.passwordResetSuccessful = passwordResetSuccessful;
	}

	/**
	 * Gets the user.
	 *
	 * @return the user
	 */
	public UserJPA getUser() {
		return user;
	}

	/**
	 * Sets the user.
	 *
	 * @param user the new user
	 */
	public void setUser(UserJPA user) {
		this.user = user;
	}

}