/** 
 * @author ngel Arias Romero. 
 * UOC - TFC SaveMeSafe 2015
 */

package managedbean;

import java.io.Serializable;
import java.util.List;
import java.util.Properties;

import javax.annotation.PostConstruct;
import javax.ejb.EJB;
import javax.faces.bean.ManagedBean;
import javax.faces.bean.ManagedProperty;
import javax.faces.bean.SessionScoped;
import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;

import jpa.AccountGroupJPA;
import jpa.AccountJPA;
import jpa.UserJPA;

import org.primefaces.model.DefaultTreeNode;
import org.primefaces.model.TreeNode;

import ejb.AccountsFacadeRemote;

// TODO: Auto-generated Javadoc
/**
 * The Class TreeMenuViewController.
 */
@ManagedBean(name = "treeContextMenuView")
@SessionScoped
public class TreeMenuViewController implements Serializable {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 1L;

	/** The root. */
	private TreeNode root;

	/** The selected node. */
	private TreeNode selectedNode;

	/** The show clear data. */
	private boolean showClearData = false;

	/** The account remote. */
	@EJB
	private AccountsFacadeRemote accountRemote;

	/** The login bean. */
	@ManagedProperty(value = "#{loginUser}")
	private LoginUserView loginBean; // +setter

	/** The current user. */
	private UserJPA currentUser = null;

	/** The service. */
	@ManagedProperty("#{dataService}")
	private TreeVewDataManagement service;

	/**
	 * Inits the.
	 */
	@PostConstruct
	public void init() {
		loadData();
	}

	/**
	 * Load data.
	 */
	public void loadData() {

		try {
			currentUser = loginBean.getCurrentUser();

			root = service.initDocuments(currentUser);

			Properties props = System.getProperties();
			Context ctx = new InitialContext(props);
			accountRemote = (AccountsFacadeRemote) ctx
					.lookup("java:app/savemesafeEJB/AccountsFacadeBean!ejb.AccountsFacadeRemote");
		} catch (NamingException e) {
			e.printStackTrace();
			throw new RuntimeException(e);
		}
	}

	/**
	 * Gets the root.
	 *
	 * @return the root
	 */
	public TreeNode getRoot() {
		return root;
	}

	/**
	 * Checks if is show clear data.
	 *
	 * @return true, if is show clear data
	 */
	public boolean isShowClearData() {
		return showClearData;
	}

	/**
	 * Sets the show clear data.
	 *
	 * @param showClearData the new show clear data
	 */
	public void setShowClearData(boolean showClearData) {
		this.showClearData = showClearData;
	}

	/**
	 * Expand all.
	 */
	public void expandAll() {
		List<TreeNode> listNode = root.getChildren();
		for (int i = 0; i < listNode.size(); i++) {
			listNode.get(i).setExpanded(true);
		}
	}

	/**
	 * Collapse all.
	 */
	public void collapseAll() {
		List<TreeNode> listNode = root.getChildren();
		for (int i = 0; i < listNode.size(); i++) {
			listNode.get(i).setExpanded(false);
		}
	}

	/**
	 * Gets the selected node.
	 *
	 * @return the selected node
	 */
	public TreeNode getSelectedNode() {
		return selectedNode;
	}

	/**
	 * Sets the selected node.
	 *
	 * @param selectedNode the new selected node
	 */
	public void setSelectedNode(TreeNode selectedNode) {
		this.selectedNode = selectedNode;
	}

	/**
	 * Sets the service.
	 *
	 * @param service the new service
	 */
	public void setService(TreeVewDataManagement service) {
		this.service = service;
	}

	/**
	 * Adds the node.
	 */
	public void addNode() {
		TreeNode newNode = service.createAccount(selectedNode);
		// Controlar que la cuenta es creada dentro del grupo actual.
		if (selectedNode.getData() instanceof AccountGroupJPA)
			selectedNode.getChildren().add(newNode);
		else {
			selectedNode.getParent().getChildren().add(newNode);
		}

		selectedNode.setExpanded(true);
		selectedNode.setSelected(false);
		newNode.setSelected(true);
		setSelectedNode(newNode);
		showClearData = true;
	}

	/**
	 * Adds the group node.
	 */
	public void addGroupNode() {
		selectedNode.setSelected(false);
		TreeNode newNode = service.createGroup(root);
		newNode.setSelected(true);
		setSelectedNode(newNode);
	}

	/**
	 * Save account.
	 */
	public void saveAccount() {

		showClearData = false;
		// Controlamos si el grupo que contiene esta cuenta est almacenado.
		AccountGroupJPA accountGroup = (AccountGroupJPA) selectedNode
				.getParent().getData();
		if (accountGroup.getId() == 0) {
			FacesMessagesWrapper.addError("No se ha almacenado el grupo "
					+ accountGroup.getName() + " que contiene a esta cuenta");
			return;
		}

		// Almacenamos cuenta.
		AccountJPA account = (AccountJPA) selectedNode.getData();
		account.setOwnerGroup(accountGroup);
		account = accountRemote.saveAccount(account);
		((DefaultTreeNode) selectedNode).setData(account);

		FacesMessagesWrapper.addInfo("Guardando cuenta",
				"Se ha guardado la cuenta " + account.getName());
	}

	/**
	 * Delete account.
	 */
	public void deleteAccount() {
		// Almacenamos cuenta.
		TreeNode parent = selectedNode.getParent();
		AccountJPA account = (AccountJPA) selectedNode.getData();

		String name = account.getName();

		selectedNode.getChildren().clear();
		selectedNode.getParent().getChildren().remove(selectedNode);
		selectedNode.setParent(null);

		selectedNode = parent;
		if (selectedNode != null) {
			selectedNode.setSelected(true);
		}

		if (accountRemote.deleteAccount(account))
			FacesMessagesWrapper.addInfo("Eliminando grupo",
					"Se ha eliminado la cuenta eliminado" + name);
		else
			FacesMessagesWrapper
					.addError("Error al eliminar la cuenta " + name);
	}

	/**
	 * Save account group.
	 */
	public void saveAccountGroup() {
		AccountGroupJPA accountGroup = (AccountGroupJPA) selectedNode.getData();

		accountGroup.setUser((UserJPA) root.getData());
		accountGroup = accountRemote.saveAccountGroup(accountGroup);
		((DefaultTreeNode) selectedNode).setData(accountGroup);

		FacesMessagesWrapper.addInfo("Guardando grupo",
				"Se ha guardado el grupo " + accountGroup.getName());
	}

	/**
	 * Delete account group.
	 */
	public void deleteAccountGroup() {
		// Almacenamos cuenta.
		AccountGroupJPA accountGroup = (AccountGroupJPA) selectedNode.getData();

		String name = accountGroup.getName();

		selectedNode.getChildren().clear();
		selectedNode.getParent().getChildren().remove(selectedNode);
		selectedNode.setParent(null);
		selectedNode = null;

		// Si despues de eliminar el grupo el arbol queda vaco creamos un nuevo
		// grupo visual.
		if (root.getChildCount() == 0) {
			TreeNode newNode = service.createGroup(root);
			newNode.setSelected(true);
			setSelectedNode(newNode);
		}

		if (accountRemote.deleteAccountGroup(accountGroup))
			FacesMessagesWrapper.addInfo("Eliminando grupo",
					"Se ha eliminado el grupo eliminado " + name);
		else
			FacesMessagesWrapper.addError("Error al eliminar el grupo " + name);
	}

	/**
	 * Gets the login bean.
	 *
	 * @return the login bean
	 */
	public LoginUserView getLoginBean() {
		return loginBean;
	}

	/**
	 * Sets the login bean.
	 *
	 * @param loginBean the new login bean
	 */
	public void setLoginBean(LoginUserView loginBean) {
		this.loginBean = loginBean;
	}
}
