/** 
 * @author ngel Arias Romero. 
 * UOC - TFC SaveMeSafe 2015
 */

package managedbean;

import java.io.Serializable;
import java.util.Collection;
import java.util.Iterator;
import java.util.Properties;

import javax.faces.bean.ManagedBean;
import javax.faces.bean.SessionScoped;
import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;

import jpa.AccountGroupJPA;
import jpa.AccountJPA;
import jpa.UserJPA;

import org.primefaces.model.DefaultTreeNode;
import org.primefaces.model.TreeNode;

import ejb.AccountsFacadeRemote;

// TODO: Auto-generated Javadoc
/**
 * The Class TreeVewDataManagement.
 */
@ManagedBean(name = "dataService")
@SessionScoped
public class TreeVewDataManagement implements Serializable {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 1L;
	
	/** The account remote. */
	private AccountsFacadeRemote accountRemote;

	/**
	 * Inits the documents.
	 *
	 * @param userName the user name
	 * @return the tree node
	 * @throws NamingException the naming exception
	 */
	public TreeNode initDocuments(UserJPA userName) throws NamingException {
		if (userName != null) {
			Properties props = System.getProperties();
			Context ctx = new InitialContext(props);
			accountRemote = (AccountsFacadeRemote) ctx
					.lookup("java:app/savemesafeEJB/AccountsFacadeBean!ejb.AccountsFacadeRemote");
			TreeNode root = new DefaultTreeNode(userName, null);

			@SuppressWarnings("unchecked")
			Collection<AccountGroupJPA> accountGroupList = (Collection<AccountGroupJPA>) accountRemote
					.listAccountGroupsByUser(userName.getName());
			if (!accountGroupList.isEmpty())
				for (Iterator<AccountGroupJPA> iter2 = accountGroupList
						.iterator(); iter2.hasNext();) {
					AccountGroupJPA grupo = iter2.next();
					TreeNode group = new DefaultTreeNode("group", grupo, root);
					group.setExpanded(true);

					Collection<AccountJPA> accountList = grupo.getAccounts();
					for (Iterator<AccountJPA> iter3 = accountList.iterator(); iter3
							.hasNext();) {
						AccountJPA cuenta = iter3.next();
						new DefaultTreeNode("account", cuenta, group);
					}
				}
			else {
				new DefaultTreeNode("group", new AccountGroupJPA(), root);
			}
			return root;
		}
		return null;
	}

	/**
	 * Creates the account.
	 *
	 * @param parent the parent
	 * @return the tree node
	 */
	public TreeNode createAccount(TreeNode parent) {
		return new DefaultTreeNode("account", new AccountJPA(), parent);
	}

	/**
	 * Creates the group.
	 *
	 * @param parent the parent
	 * @return the tree node
	 */
	public TreeNode createGroup(TreeNode parent) {
		return new DefaultTreeNode("group", new AccountGroupJPA(), parent);
	}
}