/** 
 * @author ngel Arias Romero. 
 * UOC - TFC SaveMeSafe 2015
 */

package managedbean;

import java.io.Serializable;

import javax.annotation.PostConstruct;
import javax.ejb.EJB;
import javax.faces.bean.ManagedBean;
import javax.faces.bean.ManagedProperty;
import javax.faces.bean.SessionScoped;
import javax.faces.context.FacesContext;
import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;

import jpa.UserJPA;
import ejb.AccountsFacadeRemote;
import ejb.UserFacadeRemote;

// TODO: Auto-generated Javadoc
/**
 * The Class UserProfileView.
 */
@ManagedBean(name = "userProfileBean")
@SessionScoped
public class UserProfileView implements Serializable {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 12L;

	/** The login bean. */
	@ManagedProperty(value = "#{loginUser}")
	private LoginUserView loginBean;

	/** The login remote. */
	@EJB
	private UserFacadeRemote loginRemote;

	/** The accounts remote. */
	@EJB
	private AccountsFacadeRemote accountsRemote;

	/** The current user. */
	private UserJPA currentUser;

	/**
	 * Instantiates a new user profile view.
	 */
	public UserProfileView() {
		super();
	}

	/**
	 * Inits.
	 */
	@PostConstruct
	public void init() {

		currentUser = loginBean.getCurrentUser();

		try {
			Context ctx = new InitialContext(System.getProperties());
			loginRemote = (UserFacadeRemote) ctx
					.lookup("java:app/savemesafeEJB/UserFacadeBean!ejb.UserFacadeRemote");
			accountsRemote = (AccountsFacadeRemote) ctx
					.lookup("java:app/savemesafeEJB/AccountsFacadeBean!ejb.AccountsFacadeRemote");

		} catch (NamingException e) {
			e.printStackTrace();
			throw new RuntimeException(e);
		}
	}

	/**
	 * Gets the login bean.
	 *
	 * @return the login bean
	 */
	public LoginUserView getLoginBean() {
		return loginBean;
	}

	/**
	 * Sets the login bean.
	 *
	 * @param loginBean
	 *            the new login bean
	 */
	public void setLoginBean(LoginUserView loginBean) {
		this.loginBean = loginBean;
	}

	/**
	 * Gets the current user.
	 *
	 * @return the current user
	 */
	public UserJPA getCurrentUser() {
		return currentUser;
	}

	/**
	 * Sets the current user.
	 *
	 * @param currentUser
	 *            the new current user
	 */
	public void setCurrentUser(UserJPA currentUser) {
		this.currentUser = currentUser;
	}

	/**
	 * Update user.
	 *
	 * @return the string
	 */
	public String updateUser() {

		try {

			accountsRemote.updateEncryptedData(currentUser.getName(),
					currentUser.getPassword());

			currentUser = loginRemote.updateUser(currentUser);

			FacesMessagesWrapper.addInfo(
					"Actualizacin de los datos de usuario",
					"Sus datos has sido actualizados correctamente");

		} catch (Exception e) {
			// TODO Auto-generated catch block
			FacesMessagesWrapper.addError(e.getMessage());
		}

		return "profile";
	}

	/**
	 * Delete user.
	 *
	 * @return the string
	 */
	public String deleteUser() {
		try {
			loginRemote.deleteUser(currentUser);

			FacesMessagesWrapper.addInfo(
					"Eliminacin de la cuenta y datos del usuario",
					"Sus datos has sido eliminados completamente");

			FacesContext.getCurrentInstance().getExternalContext()
					.invalidateSession();

		} catch (Exception e) {
			// TODO Auto-generated catch block
			FacesMessagesWrapper.addError(e.getMessage());
		}
		return "/public/login.xhtml";
	}
}
